import request from "../utils/request";


/**
 * 初始化接口
 * @returns 
 */
export async function getInitAppletApi() {
    return request({
        url: "/api/init/applet",
        method: 'POST',
        data: {}
    })
}

/**
 * 账号密码登录
 * @param data 
 * @returns 
 */
export async function userLoginApi(data: { username: string, password: string }) {
    return request({
        url: "/api/login/password",
        method: 'POST',
        data: {
            ...data,
            type: 1
        }
    })
}

/**
 * 公众号登录
 * @param data 
 * @returns 
 */
export async function weChatLoginApi(data: { code: string }) {
    return request({
        url: "/api/login/wx/code",
        method: 'POST',
        data
    })
}

/**
 * 手机号注册登录
 * @param data 
 * @returns 
 */
export async function userLoginmApi(data: { mobile: string, code: string }) {
    return request({
        url: "/api/login/mobile",
        method: 'POST',
        data
    })
}

/**
 * 登出
 * @param data 
 * @returns 
 */
export async function userLogoutApi() {
    return request({
        url: "/api/login/write/off",
        method: 'GET'
    })
}

/**
 * 发送验证码 
 * @param type 1 注册登录 2 修改密码 3 绑定手机 4 找回密码
 * @returns 
 */
export async function smsSendApi(data: { mobile: string, type: 1 | 2 | 3 | 4 }) {
    return request({
        url: "/api/sms/send/msg",
        method: 'POST',
        data
    })
}

/**
 * 重置密码
 * @param data 
 * @returns 
 */
export async function resetPwdApi(data: { newPassword: string, mobile: string, code: string, userName: string }) {
    return request({
        url: "/api/user/find/password",
        method: 'POST',
        data
    })
}

/**
 * 用户注册
 * @param data 
 * @returns 
 */
export async function userRegApi(data: { username: string, password: string }) {
    return request({
        url: "/api/login/password",
        method: 'POST',
        data
    })
}

/**
 * 实名认证
 * @param data 
 * @returns 
 */
export async function realNameApi(data: { cardName: string, cardId: string }) {
    return request({
        url: "/api/user/authentication",
        method: 'POST',
        data
    })
}


/**
 * 用户登录凭证时效验证
 * @returns 
 */
export async function tokenExpireTimeCheckApi() {
    return request({
        url: "/api/login/token/expireTime/check",
        method: 'GET'
    })
}


/**
 * 修改密码确定
 * @param data 
 * @returns 
 */
export async function savePassWordApi(data: { oldPassword: string, newPassword: string }) {
    return request({
        url: "/api/user/update/password",
        method: 'POST',
        data
    })
}


/**
 * 绑定手机确认
 * @param data 
 * @returns 
 */
export async function bindPhoneApi(data: { mobile: string, code: string }) {
    return request({
        url: "/api/user/bind/phone",
        method: 'POST',
        data
    })
}

/**
 * 信息上报
 * @param data 
 * @returns 
 */
export async function gameRoleEscalationApi(data: any) {
    return request({
        url: "/api/user/update/game/role",
        method: 'POST',
        data
    })
}

/**
 * 活跃上报
 * @param data 
 * @returns 
 */
export async function activeEscalationApi(data: { roleId: number, roleLevel: number, serverId: number }) {
    return request({
        url: "/api/user/active/call/role",
        method: 'POST',
        data
    })
}


/**
 * 支付
 * @param data 
 * @returns 
 */
export async function payPostReadyApi(data: any) {
    return request({
        url: "/api/pay/create",
        method: 'POST',
        data
    })
}


/**
 * 支付结果查询
 * @param params 
 * @returns 
 */
export async function payPostResultApi(params: { orderId: string }) {
    return request({
        url: "/api/pay/get/result",
        method: 'GET',
        params
    })
}


/**
 * 获取用户详细信息
 * @returns 
 */
export async function getUserDetailApi() {
    return request({
        url: "/api/user/get/detail",
        method: 'GET'
    })
}

/**
 * 
 * @param params 
 * @returns 
 */
export async function getJsApiPayInfoApi(params: { openId: string, orderId: string }) {
    return request({
        url: "/api/pay/param/mp",
        method: 'GET',
        params
    })
}

