import React, { useEffect, useState } from "react"
import '../../App.less'
import { App, Modal } from "antd"
import { isOs, isWx } from "../../utils"
import { useAjax } from "../../hooks/useAjax"
import { payPostReadyApi } from "../../api"
import { useDebounceFn } from "ahooks"
import LoadingPop from "../../components/loadingPop"
import showMessage from "../../components/showMessage"

interface Props {
    isVer: boolean
    data: any,
    open?: boolean,
    onClose?: () => void
    onChange?: (data: any, payWay: string, payInfo: any) => void
}
/**
 * 支付选择界面
 * @param param0 
 * @returns 
 */
const PayPop: React.FC<Props> = ({ open, data, onClose, onChange, isVer }) => {

    /********************************/
    const [payList, setPayList] = useState<{ payway: string, icon: string, name: string }[]>([])
    const { message } = App.useApp()
    const { run } = useDebounceFn((payWay: string) => {
        pay(payWay)
    }, { wait: 300 });

    const payPostReady = useAjax((params) => payPostReadyApi(params))
    /********************************/

    useEffect(() => {
        if (isWx()) {
            setPayList([{ payway: '2', icon: 'http://h5.84game.cn/public/image/wergcder.png', name: '微信' }])
        } else {
            setPayList([
                { payway: '1', icon: 'http://h5.84game.cn/public/image/arwec.png', name: '支付宝' },
                { payway: '2', icon: 'http://h5.84game.cn/public/image/wergcder.png', name: '微信' }
            ])
        }
    }, [data])

    const pay = (payWay: string) => {
        let params = data;
        params.payWay = payWay;
        let os = isOs()
        if (os === 'windows' || os === 'mac') { // pc
            params.payDevice = 1
        } else if (isWx()) {
            params.payDevice = 7
        } else {
            params.payDevice = 2
        }
        payPostReady.run(params).then(res => {
            if (+res.code === 200) {
                console.log(res)
                onChange?.(res.data, payWay, data)
            } else {
                showMessage.error(res.msg || '请求支付失败', message)
            }
        })
    }

console.log(data)

    return <>
        {payPostReady.loading && <LoadingPop />}

        {isVer ? <div className="pop">
            <div className="pop_body" style={{ transform: 'rotate(90deg)' }}>
                <div className="payment_head">
                    <span className="payment_amount">支付金额：<b>{data?.amount + '元'}</b></span>
                    <a className="payment_close icon_close" onClick={() => onClose?.()}></a>
                </div>
                <div className="payment_type">
                    {payList.map(item => <a className="payment_type-item" key={item.payway} onClick={() => run(item.payway)}>
                        <img src={item.icon} />
                        <span>{item.name}</span>
                    </a>)}
                </div>
            </div>
        </div> : <Modal
            open={open}
            width={300}
            centered={true}
            footer={null}
            keyboard={false}
            maskClosable={false}
            onCancel={(e) => { e.stopPropagation(); onClose?.() }}
            className={`authPop`}
            title={<div className="payment_head">
                <span className="payment_amount">支付金额：<b>{data.amount + '元'}</b></span>
            </div>}
        >
            <div className="payment_type">
                {payList.map(item => <a className="payment_type-item" key={item.payway} onClick={() => run(item.payway)}>
                    <img src={item.icon} />
                    <span>{item.name}</span>
                </a>)}
            </div>
        </Modal>}
    </>
}

export default React.memo(PayPop)