import React, { useContext } from "react"
import { Button, Form, Input } from "antd"
import { LockOutlined, UserOutlined } from "@ant-design/icons"
import { userRegApi } from "../../api"
import { useAjax } from "../../hooks/useAjax"
import { addAccount } from "../../utils"
import { setToken } from "../../utils/auth"
import { DispatchContext } from "../../App"

/**
 * 账号密码注册
 * @returns 
 */
const RegPop: React.FC = () => {

    /**************************/
    const { dispatch, state: { initData: { h5LoginLogo: logo } } } = useContext(DispatchContext)!;
    const [form] = Form.useForm()
    const userReg = useAjax((params) => userRegApi(params))
    /**************************/

    const onFinish = (values: any) => {
        delete values.passwordag
        userReg.run({ ...values, type: 0 }).then(res => {
            if (res?.data) {
                addAccount(values.username, values.password)
                dispatch({ type: 'setToken', params: { token: res?.data?.token } })
                setToken(res?.data?.token)
            }
        })
    };

    return <div className="pop">
        <div className="pop_body">
            <div className="login_head">
                <img className="login_logo" src={logo} />
                <span className="login_title">账号注册</span>
            </div>
            <div className="login_body">
                <Form
                    name="basic"
                    form={form}
                    onFinish={onFinish}
                >
                    <Form.Item name="username" style={{ marginBottom: 10 }} rules={[{ required: true, message: '请输入账号!' }]}>
                        <Input prefix={<UserOutlined />} placeholder="请输入账号" size="large" />
                    </Form.Item>
                    <Form.Item name="password" hasFeedback style={{ marginBottom: 10 }} rules={[{ required: true, message: '请输入密码!' }]}>
                        <Input.Password prefix={<LockOutlined />} placeholder="请输入密码" size="large" />
                    </Form.Item>
                    <Form.Item name="passwordag" hasFeedback dependencies={['password']} style={{ marginBottom: 20 }} rules={[
                        { required: true, message: '请再次输入密码!' },
                        ({ getFieldValue }) => ({
                            validator(_, value) {
                                if (!value || getFieldValue('password') === value) {
                                    return Promise.resolve();
                                }
                                return Promise.reject(new Error('两次输入密码不一致!'));
                            },
                        })
                    ]}>
                        <Input.Password prefix={<LockOutlined />} placeholder="请再次输入密码" size="large" />
                    </Form.Item>
                    <Form.Item style={{ marginBottom: 10 }}>
                        <Button type="primary" className="form_button" loading={userReg.loading} htmlType="submit" size="large">注册</Button>
                    </Form.Item>
                </Form>
            </div>
            <div className="login_foot" style={{ justifyContent: 'space-between' }}>
                <Button type="text" style={{ padding: 0 }} onClick={() => dispatch({ type: 'setTypeSwitch', params: { typeSwitch: 'USER_LOGIN' } })}>返回登录</Button>
                <Button type="text" style={{ padding: 0 }} onClick={() => dispatch({ type: 'setTypeSwitch', params: { typeSwitch: 'PHONE_REG' } })}>手机注册</Button>
            </div>
        </div>
    </div>
}

export default React.memo(RegPop)